@@ -1,5 +1,26 @@
-updateS <-
-function(iter, s, V, m, Zb, Zt, Time, MU.state, P, s2,
+#' Update latent states
+#'
+#' Update latent states
+#'
+#' @param iter iteration number
+#' @param s the most recent latent states
+#' @param V Network generation rules
+#' @param m The number of breaks
+#' @param Zb Z - b
+#' @param Zt  Z stacked by time
+#' @param Time The length of time
+#' @param MU.state UVU for each state
+#' @param P Transition matrix
+#' @param s2 error variance
+#' @param N.upper.tri The number of upper triangular elements
+#' @param random.perturb If \code{random.perturb} = TRUE and a single state observation is found,
+#' the latent state is randomly selected by equal weights.
+#' 
+#' @return A list of vectors containing latent states and their probabilities
+#'
+#' @export
+#'
+updateS <- function(iter, s, V, m, Zb, Zt, Time, MU.state, P, s2,
          N.upper.tri, random.perturb){
     ns <- m + 1
     MUt <- list()
